@@ -9,20 +9,17 @@ import (
 
 func descriptionCommand() *cobra.Command {
 	cmd := &cobra.Command{
-		Use:     "description REPOSITORY [DESCRIPTION]",
-		Aliases: []string{"desc"},
-		Short:   "Set or get the description for a repository",
-		Args:    cobra.MinimumNArgs(1),
+		Use:               "description REPOSITORY [DESCRIPTION]",
+		Aliases:           []string{"desc"},
+		Short:             "Set or get the description for a repository",
+		Args:              cobra.MinimumNArgs(1),
+		PersistentPreRunE: checkIfReadable,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			ctx := cmd.Context()
 			be := backend.FromContext(ctx)
 			rn := strings.TrimSuffix(args[0], ".git")
 			switch len(args) {
 			case 1:
-				if err := checkIfReadable(cmd, args); err != nil {
-					return err
-				}
-
 				desc, err := be.Description(ctx, rn)
 				if err != nil {
 					return err
