@@ -7,20 +7,17 @@ import (
 
 func hiddenCommand() *cobra.Command {
 	cmd := &cobra.Command{
-		Use:     "hidden REPOSITORY [TRUE|FALSE]",
-		Short:   "Hide or unhide a repository",
-		Aliases: []string{"hide"},
-		Args:    cobra.MinimumNArgs(1),
+		Use:               "hidden REPOSITORY [TRUE|FALSE]",
+		Short:             "Hide or unhide a repository",
+		Aliases:           []string{"hide"},
+		Args:              cobra.MinimumNArgs(1),
+		PersistentPreRunE: checkIfReadable,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			ctx := cmd.Context()
 			be := backend.FromContext(ctx)
 			repo := args[0]
 			switch len(args) {
 			case 1:
-				if err := checkIfReadable(cmd, args); err != nil {
-					return err
-				}
-
 				hidden, err := be.IsHidden(ctx, repo)
 				if err != nil {
 					return err
