@@ -9,16 +9,16 @@ import (
 	"time"
 
 	"github.com/charmbracelet/keygen"
-	"github.com/charmbracelet/log/v2"
+	"charm.land/log/v2"
 	"github.com/charmbracelet/soft-serve/pkg/backend"
 	"github.com/charmbracelet/soft-serve/pkg/config"
 	"github.com/charmbracelet/soft-serve/pkg/db"
 	"github.com/charmbracelet/soft-serve/pkg/proto"
 	"github.com/charmbracelet/soft-serve/pkg/store"
 	"github.com/charmbracelet/ssh"
-	"github.com/charmbracelet/wish/v2"
-	bm "github.com/charmbracelet/wish/v2/bubbletea"
-	rm "github.com/charmbracelet/wish/v2/recover"
+	"charm.land/wish/v2"
+	bm "charm.land/wish/v2/bubbletea"
+	rm "charm.land/wish/v2/recover"
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promauto"
 	gossh "golang.org/x/crypto/ssh"
